pub fn case_() -> CaseBuilderExpand description
A CASE expression: case_().when(cond, then).else_(other).
Named with a trailing underscore because case is not available as a plain
identifier; the SQL is unaffected.
pub fn case_() -> CaseBuilderA CASE expression: case_().when(cond, then).else_(other).
Named with a trailing underscore because case is not available as a plain
identifier; the SQL is unaffected.