distinct

Function distinct 

pub fn distinct() -> impl Mod<SelectQuery>
SELECT DISTINCT — drop duplicate result rows.

ALL is the other alternative in the grammar and is the default; writing it adds nothing, so it is not representable.