pub fn except<Q: HasCompounds>(query: impl IntoExpr) -> impl Mod<Q>Expand description
EXCEPT <select-core> — rows of this query that are not in the other. There is
no EXCEPT ALL.
pub fn except<Q: HasCompounds>(query: impl IntoExpr) -> impl Mod<Q>EXCEPT <select-core> — rows of this query that are not in the other. There is
no EXCEPT ALL.