preload_columns

Function preload_columns 

pub fn preload_columns<Q: HasSelectList>(
    columns: impl IntoExprList,
) -> impl Mod<Q>
Add to the preload result columns, which render after columns but are counted separately.

This exists for a relation loader: the mapper needs to know how many of the returned columns belong to the root object, which is SelectList::count_select_cols.