values_from_query

Function values_from_query 

pub fn values_from_query<Q: HasValues>(query: impl IntoExpr) -> impl Mod<Q>
Insert the results of a query: INSERT INTO t (cols) SELECT ….

Replaces any rows already added, because the two are alternatives in the grammar rather than things that combine. The query is written bare, so pass a query or query rather than subquery.