pub trait HasTargetTable {
// Required method
fn target_table_mut(&mut self) -> &mut TableRef;
}Expand description
A statement whose target table is separate from its from-item: the table an
UPDATE writes to, or the one a DELETE removes from.
In SQLite both are a qualified-table-name
(https://www.sqlite.org/syntax/qualified-table-name.html), which is what makes
INDEXED BY available there as well as on a FROM item.
Required Methods
Sourcefn target_table_mut(&mut self) -> &mut TableRef
fn target_table_mut(&mut self) -> &mut TableRef
The target table to modify.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".